Index: Source/core/paint/BoxDecorationData.h |
diff --git a/Source/core/paint/BoxDecorationData.h b/Source/core/paint/BoxDecorationData.h |
index 63087ffba95cdcb99333e2adec72a4e18bbaf022..7dfbdacc28cc40475836fc59924b6c89eb67df12 100644 |
--- a/Source/core/paint/BoxDecorationData.h |
+++ b/Source/core/paint/BoxDecorationData.h |
@@ -13,7 +13,7 @@ namespace blink { |
class GraphicsContext; |
class LayoutBox; |
// Information extracted from LayoutStyle for box painting. |
class BoxDecorationData { |
public: |
BoxDecorationData(const LayoutBox&, GraphicsContext*); |
@@ -26,7 +26,7 @@ public: |
private: |
BackgroundBleedAvoidance determineBackgroundBleedAvoidance(const LayoutBox&, GraphicsContext*); |
- bool borderObscuresBackgroundEdge(const LayoutStyle&, const FloatSize& contextScale) const; |
+ bool borderObscuresBackgroundEdge(const ComputedStyle&, const FloatSize& contextScale) const; |
unsigned m_bleedAvoidance : 2; // BackgroundBleedAvoidance |
}; |
@@ -13,7 +13,7 @@ namespace blink { |
class GraphicsContext; |
class LayoutBox; |
-// Information extracted from LayoutStyle for box painting. |
+// Information extracted from ComputedStyle for box painting. |
class BoxDecorationData { |
public: |